@@ -5,9 +5,9 @@
  *
  * Functions require SM_PATH and support of forms.php functions
  *
- * @copyright 1999-2014 The SquirrelMail Project Team
+ * @copyright 1999-2015 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: addressbook.php 14422 2014-01-01 20:59:43Z pdontthink $
+ * @version $Id: addressbook.php 14493 2015-01-19 18:22:19Z pdontthink $
  * @package squirrelmail
  * @subpackage addressbook
  */
@@ -350,7 +350,7 @@ class AddressBook {
      * nickname optionally prepended.
      */
 
-    function full_address($row) {
+    static function full_address($row) {
         global $data_dir, $username;
         $addrsrch_fullname = getPref($data_dir, $username, 'addrsrch_fullname', 'fullname');
 
@@ -520,11 +520,6 @@ class AddressBook {
             $userdata['nickname'] = $userdata['email'];
         }
 
-        if (preg_match('/[ :|#"!]/', $userdata['nickname'])) {
-            $this->error = _("Nickname contains illegal characters");
-            return false;
-        }
-
         /* Check that specified backend accept new entries */
         if (!$this->backends[$bnum]->writeable) {
             $this->error = _("Address book is read-only");
@@ -604,11 +599,6 @@ class AddressBook {
             return false;
         }
 
-        if (preg_match('/[: |#"!]/', $userdata['nickname'])) {
-            $this->error = _("Nickname contains illegal characters");
-            return false;
-        }
-
         if (empty($userdata['nickname'])) {
             $userdata['nickname'] = $userdata['email'];
         }
