@@ -6,9 +6,9 @@
  * This contains all messages, including information, error, and just
  * about any other message you can think of.
  *
- * @copyright 1999-2014 The SquirrelMail Project Team
+ * @copyright 1999-2015 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: display_messages.php 14422 2014-01-01 20:59:43Z pdontthink $
+ * @version $Id: display_messages.php 14479 2015-01-03 03:56:32Z pdontthink $
  * @package squirrelmail
  */
 
@@ -110,7 +110,9 @@ function logout_error( $errString, $errTitle = '' ) {
          '<font color="'.$color[2].'"><b>'.
          '<a href="'.$logout_link.'" target="'.$frame_top.'">'.
          _("Go to the login page") . '</a></b></font></td></tr>'.
-         '</table></td></tr></table></center></body></html>';
+         '</table></td></tr></table></center>'.
+         '<!-- logout_error -->'.
+         '</body></html>';
 }
 
 function error_box($string, $color) {
@@ -154,7 +156,8 @@ function error_box($string, $color) {
          '</td></tr><tr><td>'.
          '<table cellpadding="1" cellspacing="5" align="center" border="0">'.
          '<tr>' . html_tag( 'td', $string."\n", 'left') . '</tr></table>'.
-         '</td></tr></table></td></tr></table>';
+         '</td></tr></table></td></tr></table>'.
+         '<!-- error_box -->';
 }
 
 /**
