@@ -5,9 +5,9 @@
  *
  * This implements all functions that do general IMAP functions.
  *
- * @copyright 1999-2014 The SquirrelMail Project Team
+ * @copyright 1999-2015 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: imap_general.php 14436 2014-01-21 21:30:59Z pdontthink $
+ * @version $Id: imap_general.php 14479 2015-01-03 03:56:32Z pdontthink $
  * @package squirrelmail
  * @subpackage imap
  */
@@ -393,6 +393,9 @@ function sqimap_read_data_list ($imap_stream, $tag_uid, $handle_errors,
     case 'NO':
         /* ignore this error from M$ exchange, it is not fatal (aka bug) */
         if (strstr($message, 'command resulted in') === false) {
+            sqsession_register('NO', 'IMAP_FATAL_ERROR_TYPE');
+            sqsession_register($query, 'IMAP_FATAL_ERROR_QUERY');
+            sqsession_register($message, 'IMAP_FATAL_ERROR_MESSAGE');
             set_up_language($squirrelmail_language);
             require_once(SM_PATH . 'functions/display_messages.php');
             $string = "<b><font color=\"$color[2]\">\n" .
@@ -408,6 +411,9 @@ function sqimap_read_data_list ($imap_stream, $tag_uid, $handle_errors,
         }
         break;
     case 'BAD':
+        sqsession_register('BAD', 'IMAP_FATAL_ERROR_TYPE');
+        sqsession_register($query, 'IMAP_FATAL_ERROR_QUERY');
+        sqsession_register($message, 'IMAP_FATAL_ERROR_MESSAGE');
         set_up_language($squirrelmail_language);
         require_once(SM_PATH . 'functions/display_messages.php');
         $string = "<b><font color=\"$color[2]\">\n" .
@@ -421,6 +427,9 @@ function sqimap_read_data_list ($imap_stream, $tag_uid, $handle_errors,
         echo '</body></html>';
         exit;
     case 'BYE':
+        sqsession_register('BYE', 'IMAP_FATAL_ERROR_TYPE');
+        sqsession_register($query, 'IMAP_FATAL_ERROR_QUERY');
+        sqsession_register($message, 'IMAP_FATAL_ERROR_MESSAGE');
         set_up_language($squirrelmail_language);
         require_once(SM_PATH . 'functions/display_messages.php');
         $string = "<b><font color=\"$color[2]\">\n" .
@@ -434,6 +443,9 @@ function sqimap_read_data_list ($imap_stream, $tag_uid, $handle_errors,
         echo '</body></html>';
         exit;
     default:
+        sqsession_register('UNKNOWN', 'IMAP_FATAL_ERROR_TYPE');
+        sqsession_register($query, 'IMAP_FATAL_ERROR_QUERY');
+        sqsession_register($message, 'IMAP_FATAL_ERROR_MESSAGE');
         set_up_language($squirrelmail_language);
         require_once(SM_PATH . 'functions/display_messages.php');
         $string = "<b><font color=\"$color[2]\">\n" .
