@@ -6,9 +6,9 @@
  * This implements functions that manipulate messages
  * NOTE: Quite a few functions in this file are obsolete
  *
- * @copyright 1999-2014 The SquirrelMail Project Team
+ * @copyright 1999-2015 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: imap_messages.php 14422 2014-01-01 20:59:43Z pdontthink $
+ * @version $Id: imap_messages.php 14479 2015-01-03 03:56:32Z pdontthink $
  * @package squirrelmail
  * @subpackage imap
  */
@@ -44,7 +44,7 @@ function sqimap_msgs_list_copy($imap_stream, $id, $mailbox) {
  * Moves a set of messages ($id) to another mailbox ($mailbox)
  * 
  * @param int    $imap_stream   The resource ID for the IMAP socket
- * @param mixed  $id            A string or array of messages to copy
+ * @param mixed  $id            A string or array of messages to move
  * @param string $mailbox       The destination mailbox
  * @param bool   $handle_errors Show error messages in case of a NO, BAD, or BYE response
  *
@@ -1176,7 +1176,7 @@ function sqimap_toggle_flag($imap_stream, $id, $flag, $set, $handle_errors) {
     global $uid_support;
     $msgs_id = sqimap_message_list_squisher($id);
     $set_string = ($set ? '+' : '-');
-    $read = sqimap_run_command ($imap_stream, "STORE $msgs_id ".$set_string."FLAGS ($flag)", $handle_errors, $response, $message, $uid_support);
+    return sqimap_run_command ($imap_stream, "STORE $msgs_id ".$set_string."FLAGS ($flag)", $handle_errors, $response, $message, $uid_support);
 }
 
 
