@@ -6,9 +6,9 @@
  * This contains functions that display mailbox information, such as the
  * table row that has sender, date, subject, etc...
  *
- * @copyright 1999-2014 The SquirrelMail Project Team
+ * @copyright 1999-2015 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: mailbox_display.php 14422 2014-01-01 20:59:43Z pdontthink $
+ * @version $Id: mailbox_display.php 14496 2015-01-25 01:42:38Z pdontthink $
  * @package squirrelmail
  */
 
@@ -210,7 +210,6 @@ function printMessageInfo($imapConnection, $t, $not_last=true, $key, $mailbox,
         $checked = '';
     $col = 0;
     $msg['SUBJECT'] = decodeHeader($msg['SUBJECT']);
-//    $subject = processSubject($msg['SUBJECT'], $indent_array[$msg['ID']]);
     $subject = sm_truncate_string(str_replace('&nbsp;',' ',$msg['SUBJECT']), $truncate_subject, '...', TRUE);
     if (sizeof($index_order)) {
         foreach ($index_order as $index_order_part) {
@@ -225,6 +224,9 @@ function printMessageInfo($imapConnection, $t, $not_last=true, $key, $mailbox,
             case 2: /* from */
                 $from_xtra = '';
                 $from_xtra = 'title="' . $senderFrom . '"';
+                if (trim($senderName) == '') {
+                    $senderName = '(' . _("unknown") . ')';
+                }
                 echo html_tag( 'td',
                     html_tag('label',
                                $italic . $bold . $flag . $fontstr . sm_truncate_string($senderName, $truncate_sender, '...', TRUE) .
@@ -253,6 +255,9 @@ function printMessageInfo($imapConnection, $t, $not_last=true, $key, $mailbox,
                                'nowrap title="' . $date_title_string . '"' );
                 break;
             case 4: /* subject */
+                if (trim($subject) == '') {
+                    $subject = '(' . _("unknown") . ')';
+                }
                 $td_str = $bold;
                 if ($thread_sort_messages == 1) {
                     if (isset($indent_array[$msg['ID']])) {
