@@ -18,8 +18,8 @@
  *
  * Also view plugins/README.plugins for more information.
  *
- * @version $Id: filters.php 14436 2014-01-21 21:30:59Z pdontthink $
- * @copyright (c) 1999-2014 The SquirrelMail Project Team
+ * @version $Id: filters.php 14479 2015-01-03 03:56:32Z pdontthink $
+ * @copyright (c) 1999-2015 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
  * @package plugins
  * @subpackage filters
@@ -184,6 +184,23 @@ function start_filters() {
            $imap_general, $filters, $imap_stream, $imapConnection,
            $UseSeparateImapConnection, $AllowSpamFilters;
 
+    // if there were filtering errors previously during
+    // this login session, we won't try again
+    //
+    // (errors that this plugin was able to catch or a "NO"
+    // response/failure from IMAP found in the current session,
+    // which could have resulted from an attempted filter copy
+    // (over quota), in which case execution halts before this
+    // plugin can catch the problem -- note, however, that any
+    // other IMAP "NO" failure (caused by unrelated actions) at
+    // any time during the current session will cause this plugin
+    // to effectively shut down)
+    //
+    sqgetGlobalVar('filters_error', $filters_error, SQ_SESSION, FALSE);
+    sqgetGlobalVar('IMAP_FATAL_ERROR_TYPE', $imap_fatal_error, SQ_SESSION, '');
+    if ($filters_error || $imap_fatal_error == 'NO')
+        return;
+
     sqgetGlobalVar('username', $username, SQ_SESSION);
     sqgetGlobalVar('key',      $key,      SQ_COOKIE);
 
@@ -360,6 +377,14 @@ function filter_search_and_delete($imap, $where, $what, $where_to, $user_scan,
                 $id = trim($ids[$j]);
                 if (sqimap_msgs_list_move($imap, $id, $where_to)) {
                     $del_id[] = $id;
+                } else {
+                    // if errors occurred, don't try to filter again during this session
+                    sqsession_register(TRUE, 'filters_error');
+                    global $color;
+                    error_box(_("A problem occurred filtering messages. Check filter settings and account quota if applicable. Filtering is disabled for the remainder of this login session."), $color);
+                    // we stil return info about what was successfully
+                    // filtered before this error occurred
+                    return $del_id;
                 }
             }
         }
@@ -476,7 +501,13 @@ function spam_filters($imap_stream) {
     }
     // Lookie!  It's spam!  Yum!
     if (count($aSpamIds) && sqimap_mailbox_exists($imap_stream, $filters_spam_folder)) {
-        sqimap_msgs_list_move($imap_stream, $aSpamIds, $filters_spam_folder);
+        if (!sqimap_msgs_list_move($imap_stream, $aSpamIds, $filters_spam_folder)) {
+            // if errors occurred, don't try to filter again during this session
+            sqsession_register(TRUE, 'filters_error');
+            global $color;
+            error_box(_("A problem occurred filtering messages. Check filter folders and account quota if applicable. Filtering is disabled for the remainder of this login session."), $color);
+            return;
+        }
         sqimap_mailbox_expunge($imap_stream, 'INBOX', true, $aSpamIds);
     }
 
