@@ -2,10 +2,10 @@
 /**
  * mailout.php
  *
- * Copyright (c) 1999-2014 The SquirrelMail Project Team
+ * Copyright (c) 1999-2015 The SquirrelMail Project Team
  * Licensed under the GNU GPL. For full terms see the file COPYING.
  *
- * $Id: mailout.php 14422 2014-01-01 20:59:43Z pdontthink $
+ * $Id: mailout.php 14491 2015-01-09 07:24:03Z pdontthink $
  * @package plugins
  * @subpackage listcommands
  */
@@ -27,6 +27,7 @@ sqgetGlobalVar('send_to', $send_to, SQ_GET);
 sqgetGlobalVar('subject', $subject, SQ_GET);
 sqgetGlobalVar('body',    $body,    SQ_GET);
 sqgetGlobalVar('action',  $action,  SQ_GET);
+sqgetGlobalVar('identity',  $identity,  SQ_GET);
 
 switch ( $action ) {
 case 'help':
@@ -64,8 +65,10 @@ echo html_tag('p', '', 'center' ) . _("From:") . ' ';
 if (count($idents) > 1) {
     echo '<select name="identity">';
     foreach($idents as $nr=>$data) {
-        echo '<option value="' . $nr . '">' .
-            sm_encode_html_special_chars(
+        echo '<option '
+           . ($identity == $nr ? ' selected="selected" ' : '')
+           . 'value="' . $nr . '">'
+           . sm_encode_html_special_chars(
                 $data['full_name'].' <'.
                 $data['email_address'] . ">\n");
     }
