@@ -3,7 +3,7 @@
 /**
  * setup.php
  *
- * Copyright (c) 1999-2014 The SquirrelMail Project Team
+ * Copyright (c) 1999-2015 The SquirrelMail Project Team
  * Licensed under the GNU GPL. For full terms see the file COPYING.
  *
  * Implementation of RFC 2369 for SquirrelMail.
@@ -11,7 +11,7 @@
  * this plugin displays a menu which gives the user a choice of mailinglist
  * commands such as (un)subscribe, help and list archives.
  *
- * $Id: setup.php 14422 2014-01-01 20:59:43Z pdontthink $
+ * $Id: setup.php 14491 2015-01-09 07:24:03Z pdontthink $
  * @package plugins
  * @subpackage listcommands
  */
@@ -48,18 +48,48 @@ function plugin_listcommands_menu() {
 
         /* proto = {mailto,href} */
         $aActionKeys = array_keys($actions);
+        // note that we only use the first cmd/action, ignore the rest
         $proto = array_shift($aActionKeys);
         $act   = array_shift($actions);
 
         if ($proto == 'mailto') {
 
+            $identity = '';
+
             if (($cmd == 'post') || ($cmd == 'owner')) {
                 $url = 'src/compose.php?' .
                 (isset($startMessage)?'startMessage='.$startMessage.'&amp;':'');
             } else {
                 $url = "plugins/listcommands/mailout.php?action=$cmd&amp;";
+
+                // try to find which identity the mail should come from
+                include_once(SM_PATH . 'functions/identity.php');
+                $idents = get_identities();
+                // ripped from src/compose.php
+                $identities = array();
+                if (count($idents) > 1) {
+                    foreach($idents as $nr=>$data) {
+                        $enc_from_name = '"'.$data['full_name'].'" <'. $data['email_address'].'>';
+                        $identities[] = $enc_from_name;
+                    }
+
+                    $identity_match = $message->rfc822_header->findAddress($identities);
+                    if ($identity_match !== FALSE) {
+                        $identity = $identity_match;
+                    }
+                }
             }
-            $url .= 'send_to=' . str_replace('?','&amp;', $act);
+
+            // if things like subject are given, peel them off and give
+            // them to src/compose.php as is (not encoded)
+            if (strpos($act, '?') > 0) {
+               list($act, $parameters) = explode('?', $act, 2);
+               $parameters = '&amp;identity=' . $identity . '&amp;' . $parameters;
+            } else {
+               $parameters = '&amp;identity=' . $identity;
+            }
+
+            $url .= 'send_to=' . urlencode($act) . $parameters;
 
             $output[] = makeComposeLink($url, $fieldsdescr[$cmd]);
 
