@@ -3,9 +3,9 @@
 /**
  * printer_friendly frameset
  *
- * @copyright 1999-2014 The SquirrelMail Project Team
+ * @copyright 1999-2015 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: printer_friendly_main.php 14422 2014-01-01 20:59:43Z pdontthink $
+ * @version $Id: printer_friendly_main.php 14498 2015-01-26 19:57:10Z pdontthink $
  * @package squirrelmail
  */
 
@@ -32,7 +32,7 @@ if ( ! sqgetGlobalVar('mailbox',$mailbox,SQ_GET) ||
     $passed_id= (int) $passed_id;
     $view_unsafe_images = (bool) $_GET['view_unsafe_images'];
 /* end globals */
-    displayHtmlHeader( _("Printer Friendly"), '', false, true );
+    displayHtmlHeader( _("Printer Friendly"), '', false );
     echo '<frameset rows="60, *">' . "\n";
     echo '<frame src="printer_friendly_top.php" name="top_frame" '
         . 'scrolling="no" noresize="noresize" frameborder="0" />' . "\n";
@@ -44,4 +44,4 @@ if ( ! sqgetGlobalVar('mailbox',$mailbox,SQ_GET) ||
     echo "</frameset>\n";
 }
 ?>
-</html>
\ No newline at end of file
+</html>
